@@ -4,6 +4,7 @@ import json
 import click
 import subprocess
 import requests
+import pandas as pd
 from pathlib import Path
 from jinja2 import Environment, FileSystemLoader
 from hedera import Client, AccountId, PrivateKey, Hbar, FileCreateTransaction, FileContentsQuery, FileId, FileAppendTransaction, FileInfoQuery
@@ -20,27 +21,7 @@ class Network3Medusa():
     def network3_medusa(self):
         self.py2output()
         raw_json=self.output.stdout.decode('utf-8')
-        if self.command == "show interface":
-            json_dict = json.loads(raw_json)
-            first = True
-            for interface in json_dict['TABLE_interface']['ROW_interface']:
-                if first:
-                    first = False
-                    raw_json=str(interface).replace("\'", "\"")
-                    self.add_file_to_hedera(f"[{ raw_json },")
-                elif interface == json_dict['TABLE_interface']['ROW_interface'][-1]:
-                    raw_json=str(interface).replace("\'", "\"")
-                    self.append_file_to_hedera(f"{ raw_json }]")
-                else:
-                    raw_json=str(interface).replace("\'", "\"")
-                    self.append_file_to_hedera(f"{ raw_json },")
-
-            query = FileInfoQuery().setFileId(self.fileId)
-            info = query.execute(self.client)
-            print("File size according to `FileInfoQuery`: ", info.size)            
-            if WEBEX_ROOM:
-                self.send_webex_notification()
-        elif self.command == "show running-config":
+        if self.command == "show running-config":
             first = True
             for line in raw_json.split('\n'):
                 if first:
@@ -54,18 +35,29 @@ class Network3Medusa():
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)
         else:
-            self.add_file_to_hedera(raw_json)
+            first = True
+            chunks = pd.read_json(raw_json, lines=True, chunksize=6000000)
+            print("here")
+            for chunk in chunks:
+                if first:
+                    print("first chunk")
+                    self.add_file_to_hedera(chunk)
+                    print(chunk)
+                    first = False
+                else:
+                    print("next chunk")
+                    self.append_file_to_hedera(chunk)
             if WEBEX_ROOM:
                 self.send_webex_notification()
         
     def py2output(self):
         self.output = subprocess.run(["python", "call_cli.py", self.command], capture_output=True)
 
-    def add_file_to_hedera(self, raw_json):
+    def add_file_to_hedera(self, chunk):
         self.client = Client.forTestnet()
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
-        fileContents = json.dumps(raw_json)
+        fileContents = chunk
         print(fileContents)
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
@@ -76,11 +68,12 @@ class Network3Medusa():
         info = query.execute(self.client)
         print("file: ",  self.fileId.toString())
         print("File size according to `FileInfoQuery`: ", info.size)
+
     def append_file_to_hedera(self, interface):
         tran = (FileAppendTransaction()
                 .setFileId(self.fileId)
                 .setContents(interface)
-                .setMaxChunks(500)
+                .setMaxChunks(2000)
                 .setMaxTransactionFee(Hbar(2))
                 .freezeWith(self.client))
         resp = tran.execute(self.client)
